# Copyright (C) 2024-2025 LibreWeddingPlanner contributors

# frozen_string_literal: true

module Users
  class RegistrationsController < Devise::RegistrationsController
    clear_respond_to
    respond_to :json

    before_action :validate_captcha!, only: :create

    def create
      wedding = Wedding.create(slug: params[:slug])
      unless wedding.persisted?
        render json: { errors: wedding.errors.full_messages }, status: :unprocessable_entity
        return
      end

      ActsAsTenant.with_tenant(wedding) do
        super do |user|
          wedding.destroy unless user.persisted?
        end
      end
    end

    private

    def set_tenant
      set_current_tenant(nil)
    end
  end
end
